@@ -13,7 +13,7 @@ from django.conf import settings
 
 def runtests():
     test_runner = get_runner(settings)
-    failures = test_runner([], verbosity=1, interactive=True)
+    failures = test_runner(['tests'], verbosity=1, interactive=True)
     sys.exit(failures)
 
 if __name__ == '__main__':
